<?php

###############################################################################
# bosnian.php
# This is the bosnian language page for GeekLog!
# Special thanks to me and no one else for work on this project :)
#
# Copyright (C) 2004 Kenan 'bX' Hodzic
# buxus_85@hotmail.com
#       www.bx.net
#
# Iako prevod nije dovrsen kompletno, ili ako korisnici naidju na greske
# molimo da imaju razumjevanja.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'UTF-8';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Autor:',
    2 => 'opsirnije',
    3 => 'komentar(a)',
    4 => 'Edituj',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Za Administratora:',
    10 => 'Zahtjevi',
    11 => 'Tekstovi',
    12 => 'Blokovi',
    13 => 'Teme',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Korisnici',
    18 => 'SQL upit',
    19 => 'Odjava',
    20 => 'Korisnicke postavke:',
    21 => 'Korisnicko ime',
    22 => 'Korisnicki ID',
    23 => 'Sigurnosna razina',
    24 => 'Anonimus',
    25 => 'Odgovori',
    26 => 'Sljedeæi komentari su vlasnistvo onog koji ih je napisao. Mi nismo odgovorni na bilo koji nacin u vezi onoga sto autor u njima kaze.',
    27 => 'Najnoviji tekst',
    28 => 'Obrisati',
    29 => 'Nema korisnickih komentara.',
    30 => 'Stariji tekstovi',
    31 => 'Dozvoljeni HTML kodovi:',
    32 => 'Greska, neispravno korisnicko ime',
    33 => 'Greska, ne mogu pisati u log fajlove',
    34 => 'Greska',
    35 => 'Odjava',
    36 => 'on',
    37 => 'Nema korisnickih tekstova',
    38 => 'Razmjena sadrzaja',
    39 => 'Osvjezi',
    40 => '',
    41 => 'Gosti',
    42 => 'Autor:',
    43 => 'Odgovorite na ovo',
    44 => 'Parent',
    45 => 'MySQL greska broj',
    46 => 'MySQL poruka greske',
    47 => 'Korisnici',
    48 => 'Korisnicke postavke',
    49 => 'Postavke racuna',
    50 => 'Error with SQL statement',
    51 => 'pomoc',
    52 => 'Novi',
    53 => 'Administracija',
    54 => 'Ne mogu otvoriti datoteku.',
    55 => 'Greska na',
    56 => 'Glasaj',
    57 => 'Lozinka',
    58 => 'Prijava',
    59 => "Nemate jos korisnicki racun? Kreirajte ga besplatno <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">Ovdje</a>",
    60 => 'Posaljite komentar',
    61 => 'Kreiraj Novi Korisnicki racun',
    62 => 'rijeci',
    63 => 'Postavke komentara',
    64 => 'Posalji tekst mailom.',
    65 => 'Pogledaj verziju za printanje',
    66 => '',
    67 => ' ',
    68 => 'pocetna stranica',
    69 => 'kontakt',
    70 => 'trazi',
    71 => 'contribute',
    72 => 'web izvori',
    73 => '',
    74 => '',
    75 => 'poboljsana pretraga',
    76 => 'statistika web stranice',
    77 => 'Pluginovi',
    78 => '',
    79 => 'Sta je novo',
    80 => 'tekst(ovi) u posljednih',
    81 => 'tekst(ova) u zadnjih',
    82 => 'sati',
    83 => 'KOMENTARI',
    84 => '',
    85 => 'posljednih 48 sati',
    86 => 'Nema novih komentara',
    87 => 'posljednje 2 sedmice',
    88 => '',
    89 => '',
    90 => 'Pocetna stranica',
    91 => 'Stranica generisana za',
    92 => 'sekundi',
    93 => 'Copyright',
    94 => 'Svi zastitni znakovi i autorska prava su vlasnistvo njihovih navedenih vlasnika',
    95 => 'Koristeni software',
    96 => 'Korisnicke grupe',
    97 => 'Lista rijeci',
    98 => 'Dodatni software',
    99 => 'TEKSTOVI',
    100 => 'Nema novih tekstova',
    101 => '',
    102 => '',
    103 => 'DB Backups',
    104 => 'od',
    105 => 'Salji email',
    106 => 'Pregledano',
    107 => 'Test',
    108 => 'Brisi Cache',
    109 => 'Report abuse',
    110 => 'Report this post to the site admin',
    111 => '',
    112 => 'Registered Users',
    113 => 'Documentation',
    114 => 'TRACKBACKS',
    115 => 'No new trackback comments',
    116 => 'Trackback',
    117 => 'Directory',
    118 => 'Please continue reading on the next page:',
    119 => "Lost your <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">password</a>?",
    120 => 'Permanent link to this comment',
    121 => 'Comments (%d)',
    122 => 'Trackbacks (%d)',
    123 => 'All HTML is allowed',
    124 => 'Click to delete all checked items',
    125 => 'Are you sure you want to Delete all checked items?',
    126 => 'Select or de-select all items',
    127 => 'Permalink',
    128 => 'Login with OpenID:',
    129 => 'Configuration',
    130 => 'Webservices'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Posaljite komentar',
    2 => 'Postavke slanja',
    3 => 'Odjava',
    4 => 'Kreirajte korisnicki racun',
    5 => 'Korisnicko ime',
    6 => 'Stranica zahtjeva, da bi poslali komentar, da budete prijavljeni. Molimo prijavite se. Ako nemate korisnicki racun mozete ga napraviti besplatno.',
    7 => 'Vas posljedni komentar je ',
    8 => " sekundi.  Stranice zahtjevaju da prodje vise od {$_CONF['commentspeedlimit']} sekundi medju slanjem komentara",
    9 => 'Komentar',
    10 => 'Send Report',
    11 => 'Salji komentar',
    12 => 'Molim popunite Naziv teksta i Komentar da bi bilo poslano, jer je to neophodno za slanje.',
    13 => 'Vase informacije',
    14 => 'Pregled',
    15 => 'Report this post',
    16 => 'Naslov',
    17 => 'Greska',
    18 => 'Vazno',
    19 => 'Molimo Vas da se vasi komentari pridrzavaju teme.',
    20 => 'Molimo Vas da odgovarate na vec objavljene komentare umjesto da zapocinjete nove teme.',
    21 => 'Prije nego posaljete komentar, molim procitajte komentare ostalih korisnika da bi se izbjeglo ponavljanje.',
    22 => 'Koristite jednostavni naziv teksta da bi bilo jasno o cemu je rijec u va¹em tekstu.',
    23 => 'Vas email nece biti javno dostupan.',
    24 => 'Anonimni korisnik',
    25 => 'Are you sure you want to report this post to the site admin?',
    26 => '%s reported the following abusive comment post:',
    27 => 'Abuse report',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications',
    44 => 'Your Name'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Korisnicki profil za',
    2 => 'Korisnicko ime',
    3 => 'Puno ime',
    4 => 'Lozinka',
    5 => 'Email',
    6 => 'Web stranica',
    7 => 'Bio',
    8 => 'PGP kljuc',
    9 => 'Snimi informacije',
    10 => 'Posljednih 10 komentara od korisnika',
    11 => 'Nema korisnickih komentara',
    12 => 'Korisnicke preference za',
    13 => 'Email zabiljeske',
    14 => 'Ova lozinka je kreirana slucajnim izborom. Preporucljivo je promjeniti ovu lozinku sto prije prema vasim zeljama. Da biste promijenili lozinku, logirajte se i pritisnite na Korisnicke informacije u Korisnickom meniu.',
    15 => "Vas {$_CONF['site_name']} racun je uspjesno kreiran. Da biste ga mogli koristiti, morate se loginovati koristeci vase informacije. Molimo sacuvaj ovaj mail za buduce reference.",
    16 => 'Informacije o vasem korisnickom racunu',
    17 => 'Korisnicki racun ne postoji',
    18 => 'Upisana email addresa nije validna.',
    19 => 'Korisnicko ime ili email adresa koju ste unijeli vec postoji u bazi.',
    20 => 'Email adresu koju ste unijeli ne mozemo prihvatiti jer nije odgovarajuce forme',
    21 => 'Greska',
    22 => "Registriran na {$_CONF['site_name']}!",
    23 => "Kreiranjem korisnickog racuna imat cete samo prednosti na {$_CONF['site_name']} i moci cete koristiti neke funkcije koje obicni korisnici nemogu. Ako nemate racun, sve sto uradite bit ce zabiljezeno kao anoniman korisnik. Molimo zabiljezite da vas email <b><i>nikada</i></b> nece biti javno prikazan na ovom siteu.",
    24 => 'Lozinka ce biti poslana na email adresu koju ste unijeli.',
    25 => 'Zabopravili ste lozinku?',
    26 => 'Ukucajte <em>vas</em> username <em>ili</em> email addresu koju ste koristili za registraciju i kliknite Email Password. Instrukcije za kako cete postaviti novu lozinku ce biti poslate sa porukom na vas mail.',
    27 => 'Registriraj se sada!',
    28 => 'Lozinka poslana emailom',
    29 => 'forma za odjavu',
    30 => 'forma za prijavu',
    31 => 'Izabrane funkcije zahtjevaju od vas da budete rijavljeni kao clan.',
    32 => 'Potpis',
    33 => 'Nikad ne prikazuj javno',
    34 => 'Ovo je tvoje pravo ime',
    35 => 'Unesite novu lozinku za promjenu',
    36 => 'Pocinje sa http://',
    37 => 'Bit ce dodano na vase komentare',
    38 => 'Sve o vama! Svi to mogu citati',
    39 => 'Vas javni PGP kljuc',
    40 => 'Tema nema ikonu',
    41 => 'Zelite biti moderator',
    42 => 'Format datuma',
    43 => 'Maksimalno tekstova',
    44 => 'Nema boxova',
    45 => 'Postavke prikazivanja za',
    46 => 'Djelovi za izvrsavanje za',
    47 => 'Konfiguracija vijesti za',
    48 => 'Teme',
    49 => 'Nema ikone u tekstu',
    50 => 'Odznacite ovo ako niste zainteresirani',
    51 => 'Samo novi tekstovi',
    52 => 'Obicni je',
    53 => 'Primi nove vijesti svaku noc',
    54 => 'Oznaci boxove za naslove i autore koje ne zelis vidjeti.',
    55 => 'Ako ovo ostavite kako jeste, to znaci da hocete obicne selekcije boxova. Ako pocnete birati boxove, zapamtite da postavite sve one koje zelite zato jer ce obicna postavka biti zanemarena. Obicne postavke su prikazene podebljane.',
    56 => 'Autori',
    57 => 'Nacin prikazivanja',
    58 => 'Sortiraj po',
    59 => 'Limit komentara',
    60 => 'Kako zelite da se vasi komentari prikazuju?',
    61 => 'Noviji ili stariji prvo?',
    62 => 'Obicni je 100',
    63 => "Vasa lozinka vam je poslana putem emaila i trebali biste je primiti svakog momenta. Molimo pratite instrukcije koje ste dobili u poruci i zahvaljujemo vam za prijavu na {$_CONF['site_name']}",
    64 => 'Preference komentara ca',
    65 => 'Pokusajte ponoviti prijavu',
    66 => "Vjerovatno ste pogresno unijeli korisnicko ime ili lozinku. Pokusajte se ponovo prijaviti. Jeste li <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">novi korisnik</a>?",
    67 => 'Clan od',
    68 => 'Pamti me',
    69 => 'Koliko dugo da vas pamtimo od prijave?',
    70 => "Postavi izgled sitea {$_CONF['site_name']}",
    71 => "Jedna od velikih prednosti {$_CONF['site_name']} Je ta sto mozete promjeniti izgled site po vasoj volji. Da biste to mogli uciniti morate se prvo <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">registrovati</a> na {$_CONF['site_name']}. Ako ste vec clan, koristite vase podatke i prijavite se!",
    72 => 'Tema',
    73 => 'Jezik',
    74 => 'Promijeni izgled sitea!',
    75 => 'Emaileovane vijesti za',
    76 => 'Ako selektujete vrstu vijeste iz liste ispod, primit cete svaku novu pricu vezanu za tu vrstu vijest na kraju svakog dana. Izaberi jedino onu vrstu vijesti koje ti se svidjaju!',
    77 => 'Fotografija',
    78 => 'Dodaj vlastitu fotografiju!',
    79 => 'Oznaci ovdje za brisanje fotografije',
    80 => 'Prijava',
    81 => 'Salji email',
    82 => 'Posljednih 10 tekstova od korisnika',
    83 => 'Statistika slanja tekstova i komentara od korisnika',
    84 => 'Ukupan broj tekstova:',
    85 => 'Ukupan broj komentara:',
    86 => 'Pronadji sve tekstove od',
    87 => 'Vase korisnicko ime',
    88 => "Neko (vjerovatno vi) je zatrazio novu lozinku za vas korisnicki racun \"%s\" na {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\nAko ste to zaista htjeli molim kliknite na ovaj link za potvrdu:\n\n",
    89 => "Ako ne zelite to napraviti, jednostavno ignorirajte poruku (lozinka ce ostati nepromijenjena).\n\n",
    90 => 'Mozete ukucati novu lozinku za vas racun ispod. Molimo zabiljezite da ja vasa stara lozinka idalje validna dok ne posaljete novu.',
    91 => 'Postavi novu lozinku',
    92 => 'Unesi novu lozinku',
    93 => 'Vas poslijenji zahtjev za novom lozinkom je bio prije %d sekundi. Ovaj site zahtjeva barem %d sekundi izmedju zahtjeva za lozinku.',
    94 => 'Obrisi korisnicki racun "%s"',
    95 => 'Pritisni "Obrisi korisnicki racun" dugme ispod da biste izbrisali svoj racun iz nase baze podataka. Molimo zabiljezite da bilo koja vijest ili komentar poslata sa vase strane pod ovim korisnickim racunom <strong>nece</strong> biti izbrisana, nego prikazana kao da ju je poslao "Anonymous".',
    96 => 'obrisite korisnicki racun',
    97 => 'Potvrdi brisanje korisnickog racuna',
    98 => 'Dali ste sigurni da zelite izbrisati vas racun? Ako to zelite uraditi necete vise moci koristiti ovaj site kako ste prije mogli (ukoliko ne kreirate novi racun). Ako ste sigurni da to zelite uraditi ritisnite "obrisi korisnicki racun".',
    99 => 'Opcije privatnosti za ',
    100 => 'Email od administratora',
    101 => 'Dozvoli mailove od webmastera',
    102 => 'Email od korisnika',
    103 => 'Dozvoli primanje emailova od korisnika',
    104 => 'Prikazi online status',
    105 => 'Pokazi ko je online u bloku',
    106 => 'Location',
    107 => 'Shown in your public profile',
    108 => 'Confirm new password',
    109 => 'Enter the New password again here',
    110 => 'Current Password',
    111 => 'Please enter your Current password',
    112 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    113 => 'Login Attempt Failed',
    114 => 'Account Disabled',
    115 => 'Your account has been disabled, you may not login. Please contact an Administrator.',
    116 => 'Account Awaiting Activation',
    117 => 'Your account is currently awaiting activation by an administrator. You will not be able to login until your account has been approved.',
    118 => "Your {$_CONF['site_name']} account has now been activated by an administrator. You may now login to the site at the url below using your username (<username>) and password as previously emailed to you.",
    119 => 'If you have forgotten your password, you may request a new one at this url:',
    120 => 'Account Activated',
    121 => 'Service',
    122 => 'Sorry, new user registration is disabled',
    123 => "Are you a <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">new user</a>?",
    124 => 'Confirm Email',
    125 => 'You have to enter the same email address in both fields!',
    126 => 'Please repeat for confirmation',
    127 => 'To change any of these settings, you will have to enter your current password.',
    128 => 'Your Name',
    129 => 'Password &amp; Email',
    130 => 'About You',
    131 => 'Daily Digest Options',
    132 => 'Daily Digest Feature',
    133 => 'Comment Display',
    134 => 'Comment Options',
    135 => '<li>Default mode for how comments will be displayed</li><li>Default order to display comments</li><li>Set maximum number of comments to show - default is 100</li>',
    136 => 'Exclude Topics and Authors',
    137 => 'Filter Story Content',
    138 => 'Misc Settings',
    139 => 'Layout and Language',
    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
    141 => 'Privacy Settings',
    142 => 'The default setting is to allow users & admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
    143 => 'Filter Block Content',
    144 => 'Show & hide boxes',
    145 => 'Your Public Profile',
    146 => 'Password and email',
    147 => 'Edit your account password, email and autologin feature. You will need to enter the same password or email address twice as a confirmation.',
    148 => 'User Information',
    149 => 'Modify your user information that will be shown to other users.<li>The signature will be added to any comments or forum posts you made</li><li>The BIO is a brief summary of yourself to share</li><li>Share your PGP Key</li>',
    150 => 'Warning: Javascript recommended for enhanced functionality',
    156 => 'Delete Account',
    157 => 'Delete Option',
    158 => 'Time Zone',
    159 => 'This email was generated automatically. Please do not reply to this email.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled',
    163 => 'Re-Authentication Failed',
    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
    165 => 'Use Advanced Editor'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Preview',
    'pe_namepass' => 'Username &amp; Password',
    'pe_userinfo' => 'About You',
    'pe_layout' => 'Layout &amp; Language',
    'pe_content' => 'Content',
    'pe_privacy' => 'Privacy'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Nema novosti za prikazivanje.',
    2 => 'Nema novih vijesti za prikazati. Mozda nema novih vijesti za ovu vrstu ili je do necega drugog :)',
    3 => ' za temu %s',
    4 => 'Danasnji vazniji tekstovi',
    5 => 'Iduci',
    6 => 'Prijasnji',
    7 => 'First',
    8 => 'Last'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'Prilikom slanja dogodila se greska. Molimo pokusajte ponovo.',
    2 => 'Poruka je uspjesno poslana.',
    3 => 'Molimo osigurajte da koristite validnu email adresu u Primalac formi.',
    4 => 'Molimo popunite polja: Vase ime, Primalac, Naziv maila i Poruku',
    5 => 'Greska: Korisnik ne postoji.',
    6 => 'Pojavila se greska.',
    7 => 'Korisnicki profil za',
    8 => 'Korisnicko ime',
    9 => 'Korisnicki URL',
    10 => 'Salji email',
    11 => 'Vase ime:',
    12 => 'Primalac:',
    13 => 'Naziv maila:',
    14 => 'Poruka:',
    15 => 'HTML kod nece biti prikazan.',
    16 => 'Salji poruku',
    17 => 'Posalji tekst emailom',
    18 => 'Saljete (kome)',
    19 => 'Na email adresu',
    20 => 'Od',
    21 => 'Od email adrese',
    22 => 'Potrebno je sve popuniti',
    23 => "Ovaj email vam je poslan od %s sa %s zato jer je mislio da ce vas zanimati tekst s web stranice {$_CONF['site_url']}.  Ovo NIJE SPAM, i vase email adrese nisu sacuvane i nece se koristiti za daljnju upotrebu.",
    24 => 'Komentar za ovu vijest na',
    25 => 'Morate biti prijavljeni da bi mogli koristiti ovu postavku.',
    26 => 'Ovaj formular vam dozvoljava slanje emailova odredjenim korisnicima. Potrebno je popuniti sve podatke.',
    27 => 'Kratka poruka',
    28 => '%s pise: ',
    29 => "Ovo su dnevne obavijesti sa {$_CONF['site_name']} za ",
    30 => ' Dnevne obavijesti za ',
    31 => 'Naziv',
    32 => 'Datum',
    33 => 'Procitaj punu vijest na',
    34 => 'Kraj poruke',
    35 => 'Zao mi je, korisnik ne dozvoljava primanje nikakvih poruka.',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'Napredno pretrazivanje',
    2 => 'Kljucne rijeci',
    3 => 'Naslovi',
    4 => 'Svi',
    5 => 'Vrsta',
    6 => 'Tekstovi',
    7 => 'Komentari',
    8 => 'Autori',
    9 => 'Svi',
    10 => 'Pretrazivanje',
    11 => 'Rezultati pretrazivanja',
    12 => 'odgovara',
    13 => 'Rezultati pretrazivanja: Nema rezultata',
    14 => 'Nema rezultata koji odgovaraju vasem upitu',
    15 => 'Molim pokusajte ponovo.',
    16 => 'Naslov',
    17 => 'Datum',
    18 => 'Autor',
    19 => "Pretrazite bazu podataka web stranice {$_CONF['site_name']} trenutacnih i starijih tekstova",
    20 => 'Datum',
    21 => 'do',
    22 => '(Format datuma GGGG-MM-DD)',
    23 => 'Pregleda',
    24 => 'Pronadjeno %d rezultata',
    25 => 'Trazeno za',
    26 => 'upita ',
    27 => 'sekundi',
    28 => 'Nema odgovarajucih tekstova ili komentara prema vasem upitu',
    29 => 'Rezultati tekstova i komentara',
    30 => '',
    31 => 'Ovaj ponovni plug-in nije nista pronasao',
    32 => '',
    33 => 'URL',
    34 => 'Lokacija',
    35 => 'Cijeli dan',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'Vas upit mora sadrzavati vise od 3 znaka.',
    42 => 'Molim koristite format datuma GGGG-MM-DD (godina-mjesec-dan).',
    43 => 'tacan izraz',
    44 => 'sve rijeci',
    45 => 'bilo koja od ovih rijeci',
    46 => 'Iduci',
    47 => 'Prijasnji',
    48 => 'Autor',
    49 => 'Datum',
    50 => 'Hits',
    51 => '',
    52 => 'Lokacija',
    53 => 'Rezultati tekstova',
    54 => 'Rezultati komentara',
    55 => 'izraz(e)',
    56 => 'I',
    57 => 'ILI',
    58 => 'More results &gt;&gt;',
    59 => 'Results',
    60 => 'per page',
    61 => 'Refine search',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...',
    71 => 'asc',
    72 => 'desc'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Statistika stranica',
    2 => 'Ukupno posjeta na stranice',
    3 => 'Tekstova(Komentara) na stranicama',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Prvih deset procitanih tekstova',
    8 => 'Naslov teksta',
    9 => 'pregledano',
    10 => 'Na stranicama nema niti jednog teksta ili niti jedan tekst nije procitan.',
    11 => 'Prvih deset komentiranih tekstova',
    12 => 'Komentari',
    13 => 'Na stranicama nema niti jednog poslanog teksta ili teksta na kojem ima komentara.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => 'Prvih deset tekstova poslanih emailom',
    23 => 'Emailovi',
    24 => 'Niko nije poslao tekst emailom s ovih stranica.',
    25 => 'Top Ten Trackback Commented Stories',
    26 => 'No trackback comments found.',
    27 => 'Number of active users',
    28 => '',
    29 => '',
    30 => 'Hits',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Linkovi u tekstu',
    2 => 'Posalji tekst emailom',
    3 => 'Tekst za printanje',
    4 => 'Opcije teksta',
    5 => '',
    6 => 'Subscribe to \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => 'Za prijavljivanje %s potrebno je biti ulogiran.',
    2 => 'Prijava',
    3 => 'Novi korisnik',
    4 => '',
    5 => '',
    6 => 'Posaljite tekst',
    7 => 'Login je potreban',
    8 => 'Potvrdi',
    9 => 'Kada saljete potrebne informacije na ovaj site pitamo dali pratite slijedece sugestije suggestions...<ul><li>Popuni sva polja, ona su obavezna<li>Omoguci kompletne i tacne informacije<li>Dva puta provjeti ove URLove</ul>',
    10 => 'Naziv',
    11 => '',
    12 => 'Pocinje dana',
    13 => 'Zavrsava dana',
    14 => 'Lokacija',
    15 => 'Opis',
    16 => '',
    17 => '',
    18 => '',
    19 => 'Procitaj prvo',
    20 => '',
    21 => '',
    22 => 'Greska: Popunite sva polja',
    23 => 'Molimo popunite sva polja. Sva polja su obavezna.',
    24 => 'Submisia spasena',
    25 => 'Vasa %s submisia je uspjesno spasena.',
    26 => 'Ogranicena brzina',
    27 => 'Korisnicko ime',
    28 => 'Topic',
    29 => 'Tekst',
    30 => 'Vasa poslijednja submisia bila je prije ',
    31 => " sekunda. Ovaj site zahtjeva barem {$_CONF['speedlimit']} sekundi izmedju submisia",
    32 => 'Pregledaj',
    33 => 'Pregledaj tekst',
    34 => 'Odjava',
    35 => 'HTML kodovi nisu dozvoljeni',
    36 => 'Nacin slanja',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Adresa 1',
    45 => 'Adresa 2',
    46 => 'Grad',
    47 => 'Drzava',
    48 => 'Zip kod',
    49 => '',
    50 => '',
    51 => 'Lokacija',
    52 => 'Izbrisi',
    53 => 'Kreiraj racun',
    54 => 'Story Introduction',
    55 => 'Story Body'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Autorizacija potrebna',
    2 => 'Odbijeno! Neispravne prijavne informacije.',
    3 => 'Neispravna lozinka za korisnika',
    4 => 'Korisnièko ime:',
    5 => 'lozinka:',
    6 => 'Svaki pokusaj pristupanja administratorskom dijelu bit æe logiran i provjeren.<br' . XHTML . '>Ovi djelovi su SAMO za OVLA©TENE osobe Svaka zloporaba æe biti sankcionirana.',
    7 => 'prijava'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Neispravna Administracijska prava',
    2 => 'Nemate potrebna prava da biste uredili ovaj Blok.',
    3 => 'Blok Editor',
    4 => 'Pojavio se problem citajuci ovaj dio (pogledaj error.log za detalje).',
    5 => '',
    6 => '',
    7 => 'Svi',
    8 => 'Sigurnosni nivo Bloka',
    9 => 'Zadatak Bloka',
    10 => '',
    11 => 'Portalni Blok',
    12 => 'Normalni Blok',
    13 => 'Opcije Portalnog Bloka',
    14 => 'RSS URL',
    15 => 'Poslijednji RSS Update',
    16 => 'Opcije Normalnog Bloka',
    17 => 'Sadrzaj Bloka',
    18 => 'Molimo popunite Naziv Bloka i polja sa sadrzajem',
    19 => 'Blok Menadzer',
    20 => '',
    21 => 'Specijalni nivo Bloka',
    22 => '',
    23 => 'Zadatak Bloka',
    24 => '',
    25 => 'Da biste modifikovali Blok ili ga izbrisali, kliknite dole na zeljeni link. Da biste napravili novi Blok, pritisnite na novi blok iznad.',
    26 => 'Izgled Bloka',
    27 => 'PHP Blok',
    28 => 'Opcije PHP Bloka',
    29 => 'Funkcije Bloka',
    30 => 'Ako zelite da imate jedan svoj Blok koristi PHP kod, upisi ime funkcije iznad. Ime tvoje funkcije mora poceti sa prefiksom "phpblock_" (npr. phpblock_getweather). Ako nema ovaj prefiks, tvoja funkcija NECE biti pozvana. Ovo radimo radi toga da bismo zadrzali ljude (HACKERI) koji su mozda uspjeli upasti u vas proces insllacije mjenjajuci neke funkcije i pozivajuci se na njih i koje mogu biti stetne za vas sistem. Budite sigurni da negdje ne ostavite prazne zagrade "()" poslije vaseg imena funkcije. Na poslijetku, preporucljivo je da smjestite sve svoje PHP kodove Blokova u /path/to/geeklog/system/lib-custom.php. To ce omoguciti kodu da ostane sa tobom i na mjestu i kada nadogradis svoju verziju Geekloga.',
    31 => 'Greska u PHP Bloku. Funkcija, %s, ne postoji.',
    32 => 'Greska, nedostaje/u polje/a',
    33 => 'Moras navesti URL za pristup RSS fileu za portalni blok',
    34 => 'Moras navesti naziv i funkciju za PHP blokove',
    35 => 'Moras upisati naziv i sadrzaj za normalne blokove',
    36 => 'Moras upisati sadrzaj za izgled blokova',
    37 => 'Lose ime funkcije PHP bloka',
    38 => 'Funkcije za PHP Blokove moraju imati prefiks \'phpblock_\' (npr. phpblock_getweather). Prefiks \'phpblock_\' je potreban iz sigurnosnih razloga da bi zastitio dio koda za izvrsavanje.',
    39 => 'Strana',
    40 => 'Lijevo',
    41 => 'Desno',
    42 => 'Moras navesti Ime Bloka i Namjenu Bloka za obicne Geeklog blokove.',
    43 => 'Jedino na pocetnoj strani(Home/index)',
    44 => '',
    45 => "Pokusavas pristupati bloku za koji nemas prava pristupa. Ovaj pokusaj pristupa je zabiljezen. Molimo <a href=\"{$_CONF['site_admin_url']}/block.php\">vratite se nazad</a>.",
    46 => 'Novi Block',
    47 => '',
    48 => 'Naziv Bloka',
    49 => ' (nema odvajanja i mora biti jedinstven)',
    50 => 'The Block Name can not be empty',
    51 => 'ukljucujuci http://',
    52 => 'Ako ostavite ovo praznim help ikona za ovaj blok se nece prikazati',
    53 => 'Omoguci',
    54 => 'spasi',
    55 => 'odustani',
    56 => 'izbrisi',
    57 => 'Pomjeri Blok dole',
    58 => 'Pomjeri Blok gore',
    59 => 'Prebaci Blok na desnu stranu',
    60 => 'Prebaci Blok na lijevu stranu',
    61 => 'No Title',
    62 => 'Article Limit',
    63 => 'Bad Block Title',
    64 => 'Your Title must not be empty and cannot contain HTML!',
    65 => 'Order',
    66 => 'Autotags',
    67 => 'Check to allow autotags',
    68 => 'The feed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'Prethodni tekst',
    2 => 'Iduci tekst',
    3 => 'Mode',
    4 => 'Postavke slanja',
    5 => 'Editiranje teksta',
    6 => 'Nema teksta u sistemu.',
    7 => 'Autor',
    8 => 'snimi',
    9 => 'pregled',
    10 => 'ponisti',
    11 => 'obrisi',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Datum',
    16 => 'Uvodni tekst',
    17 => 'Tijelo teksta',
    18 => 'Posjeta',
    19 => 'Komentari',
    20 => 'Ping',
    21 => 'Send Ping',
    22 => 'Popis tekstova',
    23 => 'Da biste uredili ili izbrisali vijest, pritisnite an broj vijesti ispod. Da biste pregledali vijest, pritisnite na naziv vijesti koju zelite pregledati. Ako zelite napisati novu vijest izaberite opciju nova vijest iznad.',
    24 => 'The ID you chose for this story is already in use. Please use another ID.',
    25 => 'Error when saving story',
    26 => 'Pregled teksta',
    27 => 'If you use [unscaledX] instead of [imageX], the image will be inserted at its original dimensions.',
    28 => '<p><b>PREVIEWING</b>: Previewing a story with images attached is best done by saving the article as a draft INSTEAD OF hitting the preview button.  Use the preview button only when images are not attached.',
    29 => 'Trackbacks',
    30 => 'Greska u uploadanju datoteke',
    31 => 'Molimo popunite polja sa Nazivom i Uvodnim tekstom',
    32 => 'Featured',
    33 => 'There can only be one featured story',
    34 => 'Draft',
    35 => 'Da',
    36 => 'Ne',
    37 => 'Vise od',
    38 => 'Vise sa',
    39 => 'Emailovi',
    40 => '',
    41 => "Pokusavas pristupati vijesti za koju nemas prava pristupa. Ovaj pokusaj pristupa je zabiljezen. Mozete pogledati vijest u dijelu read-only ispod. Molimo <a href=\"{$_CONF['site_admin_url']}/story.php\">vratite se nazad</a> kada zavrsite.",
    42 => "Pokusavas pristupati vijesti za koju nemas prava pristupa. Ovaj pokusaj pristupa je zabiljezen. Molimo <a href=\"{$_CONF['site_admin_url']}/story.php\">vratite se nazad</a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>ZABILJESKA:</b> ako uredite ovaj datum da se prikaze u buducnosti, ova vijest se nece objaviti sve do tog datuma. To takodje znaci da ta vijest nece biti ukljucena u vas RSS headline feed i biti ce ignorirana u stranicama za pretrazivanje i statickim stranicama.',
    47 => 'Slike',
    48 => 'slika',
    49 => 'desno',
    50 => 'lijevo',
    51 => 'Da biste dodali jednu od vasih slika odredjenoj vijesti morate ubaciti specijano formirani tekst. Taj tekst izgleda ovako [imageX], [imageX_right] ili [imageX_left] gdje je X broj slike koju ste ubacili. ZABILJESKA: Morate koristiti sliku koju ste vec odabrali za tu vijest. Ako to ne ucinite necete moci spasiti vasu vijest.<BR><P><B>PREGLED</B>: Pregled price sa ubacenom slikom je najbolje kada se prvo spasi slika kao draft umjesto pritiska dugmeta preview. Koristite dugme preview jedino kada u tekst nije ukljucena slika.',
    52 => '',
    53 => 'nije koristena. Morate ukljuciti ovu sliku u intro ili body prije nego spasite vase izmjene',
    54 => 'Ukljucene slike nisu koristene',
    55 => 'The following errors occured while trying to save your story.  Please correct these errors before saving',
    56 => 'Prikazi ikonu teme',
    57 => 'View unscaled image',
    58 => 'Story Management',
    59 => 'Option',
    60 => '',
    61 => 'Auto Archive',
    62 => 'Auto Delete',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Expand the Content Edit Area size',
    68 => 'Reduce the Content Edit Area size',
    69 => 'Publish Story Date',
    70 => 'Toolbar Selection',
    71 => 'Basic Toolbar',
    72 => 'Common Toolbar',
    73 => 'Advanced Toolbar',
    74 => 'Advanced II Toolbar',
    75 => 'Full Featured',
    76 => 'Publish Options',
    77 => 'Javascript needs to be enabled for Advanced Editor. Option can be disabled in the main site config.php',
    78 => 'Click <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">here</a> to use default editor',
    79 => 'Preview',
    80 => 'Editor',
    81 => 'Publish Options',
    82 => 'Images',
    83 => 'Archive Options',
    84 => 'Permissions',
    85 => 'Show All',
    86 => 'Advanced Editor',
    87 => 'Story Stats',
    88 => 'Wiki-style format',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Topic Editor',
    2 => 'Topic ID',
    3 => 'Topic Name',
    4 => 'Topic Image',
    5 => '(do not use spaces)',
    6 => 'Deleting a topic deletes all stories and blocks associated with it',
    7 => 'Please fill in the Topic ID and Topic Name fields',
    8 => 'Topic Manager',
    9 => 'To modify or delete a topic, click on that topic.  To create a new topic click the new topic button to the left. You will find your access level for each topic in parenthesis. The asterisk(*) denotes the default topic.',
    10 => 'Sortirano po',
    11 => 'Stories/Page',
    12 => 'Pristup odbijen.',
    13 => "You are trying to access a topic that you don't have rights to.  This attempt has been logged. Please <a href=\"{$_CONF['site_admin_url']}/topic.php\">go back to the topic administration screen</a>.",
    14 => 'Metode sortiranja',
    15 => 'abecedno',
    16 => 'default is',
    17 => 'Nova tema',
    18 => 'Admin Home',
    19 => 'snimi',
    20 => 'ponisti',
    21 => 'obrisi',
    22 => 'Default',
    23 => 'make this the default topic for new story submissions',
    24 => '(*)',
    25 => 'Archive Topic',
    26 => 'make this the default topic for archived stories. Only one topic allowed.',
    27 => 'Or Upload Topic Icon',
    28 => 'Maximum',
    29 => 'File Upload Errors',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Korisnicko uredjivanje',
    2 => 'Korisnicki ID',
    3 => 'Korisnicko ime',
    4 => 'Ime i prezime',
    5 => 'Lozinka',
    6 => 'Sigurnosna razina',
    7 => 'Email adresa',
    8 => 'Pocetna stranica',
    9 => '(ne koristite prazan prostor)',
    10 => 'Please fill in the Username and Email Address fields',
    11 => 'Uredjivanje korisnika',
    12 => 'To modify or delete a user, click on that user below.  To create a new user click the new user button to the left. You can do simple searches by entering parts of a username, email address or fullname (e.g. *son* or *.edu) in the form below.',
    13 => 'Sigurnosna razina',
    14 => 'Datum registracije',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'snimi',
    21 => 'The username you tried saving already exists.',
    22 => 'Greska',
    23 => 'Batch Add',
    24 => 'Batch Import of Users',
    25 => 'You can import a batch of users into Geeklog.  The import file must be a tab-delimited text file and must have the fields in the following order: full name, username, email address.  Each user you import will be emailed with a random password.  You must have one user entered per line.  Failure to follow these instructions will cause problems that may require manual work so double check your entries!',
    26 => '',
    27 => '',
    28 => 'Oznacite ovdje da bi obrisali sliku.',
    29 => 'Path',
    30 => 'Uvezi',
    31 => 'Novi korisnici',
    32 => 'Done processing. Imported %d and encountered %d failures',
    33 => 'potvrdi',
    34 => 'Error: You must specify a file to upload.',
    35 => 'Zadnji put prijavljen',
    36 => '(nikada)',
    37 => 'UID',
    38 => 'Group Listing',
    39 => 'Password (again)',
    40 => 'Registration Date',
    41 => 'Last login Date',
    42 => 'Banned',
    43 => 'Awaiting Activation',
    44 => 'Awaiting Authorization',
    45 => 'Active',
    46 => 'User Status',
    47 => 'Edit',
    48 => 'Show Admin Groups',
    49 => 'Admin Group',
    50 => 'Check to allow filtering this group as an Admin Use Group',
    51 => 'Online Days',
    52 => '<br' . XHTML . '>Note: "Online Days" is the number of days between the first registration and the last login.',
    53 => 'registered',
    54 => 'Batch Delete',
    55 => 'This only works if you have <code>$_CONF[\'lastlogin\'] = true;</code> in your config.php',
    56 => 'Please choose the type of user you want to delete and press "Update List". Then, uncheck those from the list you do not want to delete and press "Delete". Please note that you will only delete those that are currently visible in case the list spans over several pages.',
    57 => 'Phantom users',
    58 => 'Short-Time Users',
    59 => 'Old Users',
    60 => 'Users that registered more than ',
    61 => ' months ago, but never logged in.',
    62 => 'Users that registered more than ',
    63 => ' months ago, then logged in within 24 hours, but since then never came back to your site.',
    64 => 'Normal users, who simply did not visit your site since ',
    65 => ' months.',
    66 => 'Update List',
    67 => 'Months since registration',
    68 => 'Online Hours',
    69 => 'Offline Months',
    70 => 'could not be deleted',
    71 => 'sucessfully deleted',
    72 => 'No User selected for deletion',
    73 => 'Are You sure you want to permanently delete ALL selected users?',
    74 => 'Recent Users',
    75 => 'Users that registered in the last ',
    76 => ' months',
    77 => 'Email site login reminder to selected users',
    78 => 'Send Reminder',
    79 => 'No User selected for reminders',
    80 => 'Successfully sent Reminders',
    81 => 'Reminder to verify account for %s',
    82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
    83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
    84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
    85 => 'If you have forgotten the password use the following link: %s',
    86 => 'Include',
    87 => 'Reminders',
    88 => 'Default Group',
    89 => 'Check to make this a default group for new users',
    90 => 'Apply "Default Group" change to existing user accounts'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Prihvati',
    2 => 'Obrisi',
    3 => 'Azuriraj',
    4 => 'Profil',
    10 => 'Naziv',
    11 => 'Pocinje dana',
    12 => 'URL',
    13 => 'Kategorija',
    14 => 'Datum',
    15 => 'Tema',
    16 => 'Username',
    17 => 'Full name',
    18 => 'Email',
    34 => 'Command and Control',
    35 => 'Zahtjev za postavljanje teksta.',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Potvrdi',
    39 => 'Trenutacno nema zahtjeva za administraciju-',
    40 => 'Zahtjev za reg. novih korisnika',
    41 => 'Comment Submissions',
    42 => 'Username',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']} Mail postavke",
    2 => 'Od',
    3 => 'Za',
    4 => 'Tema',
    5 => 'Tijelo teksta',
    6 => 'Salji:',
    7 => 'Svi korisnici',
    8 => 'Admin',
    9 => 'Opcije',
    10 => 'HTML',
    11 => 'Hitno!',
    12 => 'Salji',
    13 => 'Ponisti',
    14 => 'Ignoriraj postavke korisnika',
    15 => 'Greska kad saljem: ',
    16 => 'Uspjesno je poslana poruka za: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Salji jos poruka</a>",
    18 => 'Za',
    19 => 'NOTE: if you wish to send a message to all site members, select the Logged-in Users group from the drop down.',
    20 => "Successfully sent <successcount> messages and unsuccessfully sent <failcount> messages.  If you need them, the details of each message attempts is below.  Otherwise you can <a href=\"{$_CONF['site_admin_url']}/mail.php\">Send another message</a> or you can <a href=\"{$_CONF['site_admin_url']}/moderation.php\">go back to the administration page</a>.",
    21 => 'Failures',
    22 => 'Successes',
    23 => 'No failures',
    24 => 'No successes',
    25 => '-- Odaberite grupu --',
    26 => 'Please fill in all the fields on the form and select a group of users from the drop down.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'Installing plugins could possibly cause damage to your Geeklog installation and, possibly, to your system.  It is important that you only install plugins downloaded from the <a href="http://www.geeklog.net">Geeklog Homepage</a> as we thoroughly test all plugins submitted to our site on a variety of operating systems.  It is important that you understand that the plugin installation process will require the execution of a few filesystem commands which could lead to security problems particularly if you use plugins from third party sites.  Even with this warning you are getting, we do not gaurantee the success of any installation nor are we liable for damage caused by installing a Geeklog plugin.  In other words, install at your own risk.  For the wary, directions on how to manually install a plugin is included with each plugin package.',
    2 => 'Plug-in Installation Disclaimer',
    3 => 'Plug-in Installation Form',
    4 => 'Plug-in File',
    5 => 'Plug-in List',
    6 => 'Warning: Plug-in Already Installed!',
    7 => 'The plug-in you are trying to install already exists.  Please delete the plugin before re-installing it',
    8 => 'Plugin Compatibility Check Failed',
    9 => 'This plugin requires a newer version of Geeklog. Either upgrade your copy of <a href="http://www.geeklog.net">Geeklog</a> or get a newer version of the plug-in.',
    10 => '<br' . XHTML . '><b>There are no plugins currently installed.</b><br' . XHTML . '><br' . XHTML . '>',
    11 => 'To modify or delete a plug-in, click on that plug-in\'s number below. To learn more about a plug-in, click the plug-in name and you will be directed to that plug-in\'s website. To install or upgrade a plug-in please consult its documentation.',
    12 => 'no plugin name provided to plugineditor()',
    13 => 'Plugin Editor',
    14 => 'Novi plugin',
    15 => 'Administracija',
    16 => 'Plug-in Name',
    17 => 'Plug-in Version',
    18 => 'Geeklog Version',
    19 => 'Enabled',
    20 => 'Da',
    21 => 'Ne',
    22 => 'Instaliraj',
    23 => 'Snimi',
    24 => 'Ponisti',
    25 => 'Obrisi',
    26 => 'Ime plugina',
    27 => 'Web stranica plugina',
    28 => 'Verzija plugina',
    29 => 'Geeklog Version',
    30 => 'Obrisati plugin?',
    31 => 'Are you sure you want to delete this plug-in?  By doing so you will remove all the data and data structures that this plug-in uses.  If you are sure, click delete again on the form below.',
    32 => '<p><b>Error AutoLink tag not correct format</b></p>',
    33 => 'Code Version',
    34 => 'Update',
    35 => 'Edit',
    36 => 'Code',
    37 => 'Data',
    38 => 'Update!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'create feed',
    2 => 'snimi',
    3 => 'obrisi',
    4 => 'ponisti',
    10 => 'Razmjena sadrzaja',
    11 => 'New Feed',
    12 => 'Administracija',
    13 => 'To modify or delete a feed, click on the feed\'s title below. To create a new feed, click on New Feed above.',
    14 => 'Naslov',
    15 => 'Vrsta',
    16 => 'Ime datoteke',
    17 => 'Format',
    18 => 'zadnja obnova',
    19 => 'Enabled',
    20 => 'Da',
    21 => 'Ne',
    22 => '<i>(no feeds)</i>',
    23 => 'all Stories',
    24 => 'Feed Editor',
    25 => 'Feed Title',
    26 => 'Ogranièenje',
    27 => 'Length of entries',
    28 => '(0 = nema teksta, 1 = puni tekst, ostalo = ogranièen broj znakova.)',
    29 => 'Opis',
    30 => 'Zadnja obnova',
    31 => 'Character Set',
    32 => 'Jezik',
    33 => 'Contents',
    34 => 'Entries',
    35 => 'Sati',
    36 => 'Select type of feed',
    37 => '',
    38 => 'Greska: Nepotpun unos',
    39 => 'Please fill in the Feed Title, Description, and Filename.',
    40 => 'Please enter a  number of entries or number of hours.',
    41 => 'Linkovi',
    42 => '',
    43 => 'All',
    44 => 'None',
    45 => 'Header-link in topic',
    46 => 'Limit Results',
    47 => 'Search',
    48 => 'Edit',
    49 => 'Feed Logo',
    50 => "Relative to site url ({$_CONF['site_url']})",
    51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
    52 => 'Error: existing Filename',
    53 => 'All Frontpage Stories',
    54 => 'Please select the type of feed to create.',
    55 => 'Articles'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "Vasa lozinka vam je poslana emailom. Molimo slijedite upute u tekstu i zahvaljujemo vam sto koristite {$_CONF['site_name']}",
    2 => "Hvala sto ste poslali tekst na {$_CONF['site_name']}. Tekst ce prvo biti procitan od strane admina. Ako tekst bude prihvacen uskoro ce biti javno dostupan na nasim stranicama.",
    3 => '',
    4 => '',
    5 => 'Your account information has been successfully saved.',
    6 => 'Vase preference su uspjesno spasene.',
    7 => 'Vase komentatorske preference su uspjesno spasene.',
    8 => 'Uspjesno ste odjavljeni.',
    9 => 'Vas tekst je uspjesno snimljen.',
    10 => 'Tekst je uspjesno obrisan.',
    11 => 'Vas blok je uspjesno spasen.',
    12 => 'Blok je uspjesno izbrisan.',
    13 => 'Vasa Vrsta vijesti je uspjesno spasena.',
    14 => 'Vrsta vijesti i sve price i blokovi su uspjesno izbrisani.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Korisnik uspjesno pohranjen u bazu podataka.',
    22 => 'Korisnik uspjesno izbrisan.',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Poruka je uspjesno poslana.',
    28 => 'Plug-in je uspjesno spasen',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Pristup odbijen',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Poruka sistema',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Plug-in uspjesno instaliran!',
    45 => 'Plug-in uspjesno izbrisan.',
    46 => '',
    47 => '',
    48 => "Zahvaljujemo vam sto ste postali clan {$_CONF['site_name']}. Nas tim ce pregledati i ocjeniti vas zahtjev. Ako bude prihvacen vasa lozinka ce vam biti poslata na vas mail.",
    49 => 'Vasa grupa je uspjesno spasena.',
    50 => 'Grupa je uspjesno izbrisana.',
    51 => 'Ovaj username je vec u upotrebi. Molimo izaberite drugi.',
    52 => 'Izgleda da email adresa koju ste poslali nije validna.',
    53 => 'Vasa nova lozinka je prihvacena. Molimo koristite vasu novu lozinku da bi se prijavili ispod.',
    54 => 'Vas zahtjev za novom lozinkom je istekao. Pokusajte ponovo ispod.',
    55 => 'An email has been sent to you and should arrive momentarily. Please follow the directions in the message to set a new password for your account.',
    56 => 'Ovaj email je vec u upotrebi za drugi racun.',
    57 => 'Vas racun je uspjesno izbrisan.',
    58 => 'Your feed has been successfully saved.',
    59 => 'The feed has been successfully deleted.',
    60 => 'The plugin was successfully updated',
    61 => 'Plugin %s: Unknown message placeholder',
    62 => 'The trackback comment has been deleted.',
    63 => 'An error occurred when deleting the trackback comment.',
    64 => 'Your trackback comment has been successfully sent.',
    65 => 'Weblog directory service successfully saved.',
    66 => 'The weblog directory service has been deleted.',
    67 => 'The new password does not match the confirmation password!',
    68 => 'You have to enter the correct current password.',
    69 => 'Your account has been blocked!',
    70 => 'Your account is awaiting administrator approval.',
    71 => 'Your account has now been confirmed and is awaiting administrator approval.',
    72 => 'An error occured while attempting to install the plugin. See error.log for details.',
    73 => 'An error occured while attempting to uninstall the plugin. See error.log for details.',
    74 => 'The pingback has been successfully sent.',
    75 => 'Trackbacks must be sent using a POST request.',
    76 => 'Do you really want to delete this item?',
    77 => 'WARNING:<br' . XHTML . '>You have set your default encoding to UTF-8. However, your server does not support multibyte encodings. Please install mbstring functions for PHP or choose a different character set/language.',
    78 => 'Please make sure that the email address and the confirmation email address are the same.',
    79 => 'The page you have been trying to open refers to a function that no longer exists on this site.',
    80 => 'The plugin that created this feed is currently disabled. You will not be able to edit this feed until you re-enable the parent plugin.',
    81 => 'You may have mistyped your login credentials.  Please try logging in again below.',
    82 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    83 => 'To change your password, email address, or for how long to remember you, please enter your current password.',
    84 => 'To delete your account, please enter your current password.',
    85 => 'There was a problem sending the email.',
    86 => 'The OpenID server invalidated your login attempt.',
    87 => 'OpenID login operation cancelled by user.',
    88 => 'The OpenID server returned an error.',
    89 => 'Unable to find an OpenID server for the given identity URL.',
    90 => 'OpenID identification cancelled.',
    91 => 'You specified an invalid identity URL.',
    92 => "Please <a href=\"{$_CONF['site_admin_url']}/sectest.php\">check the security of your site</a> before using it!",
    93 => 'Database back up was successful.',
    94 => 'Backup Failed: Filesize less than 1kb',
    95 => 'There was an error.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Pristup',
    'ownerroot' => 'Vlasnik/Administrator',
    'group' => 'Grupa',
    'readonly' => 'Samo citanje',
    'accessrights' => 'Prava pristupa',
    'owner' => 'Vlasnik',
    'grantgrouplabel' => 'Grant Above Group Edit Rights',
    'permmsg' => 'NOTE: members is all logged in members of the site and anonymous is all users browsing the site that aren\'t logged in.',
    'securitygroups' => 'Security Groups',
    'editrootmsg' => "Even though you are a User Administrator, you can't edit a root user without first being a root user yourself.  You can edit all other users except root users. Please note that all attempts to illegally edit root users are logged.  Please go back to the <a href=\"{$_CONF['site_admin_url']}/user.php\">User Administration page</a>.",
    'securitygroupsmsg' => 'Select the checkboxes for the groups you want the user to belong to.',
    'groupeditor' => 'Group Editor',
    'description' => 'Opis',
    'name' => 'Ime',
    'rights' => 'Prava',
    'missingfields' => 'Polja koja nedostaju',
    'missingfieldsmsg' => 'You must supply the name and a description for a group',
    'groupmanager' => 'Sef grupe',
    'newgroupmsg' => 'To modify or delete a group, click on that group below. To create a new group click new group above. Please note that core groups cannot be deleted because they are used in the system.',
    'groupname' => 'Ime grupe',
    'coregroup' => 'Sistemska grupa',
    'yes' => 'Da',
    'no' => 'Ne',
    'corerightsdescr' => "This group is a core {$_CONF['site_name']} Group.  Therefore the rights for this group cannot be edited.  Below is a read-only list of the rights this group has access to.",
    'groupmsg' => 'Security Groups on this site are hierarchical.  By adding this group to any of the groups below you will giving this group the same rights that those groups have.  Where possible it is encouraged you use the groups below to give rights to a group.  If you need this group to have custom rights then you can select the rights to various site features in the section below called \'Rights\'.  To add this group to any of the ones below simply check the box next to the group(s) that you want.',
    'coregroupmsg' => "This group is a core {$_CONF['site_name']} Group.  Therefore the groups that this group belongs to cannot be edited.  Below is a read-only list of the groups this group belongs to.",
    'rightsdescr' => 'A groups access to a certain right below can be given directly to the group OR to a different group that this group is a part of.  The ones you see below without a checkbox are the rights that have been given to this group because it belongs to another group with that right.  The rights with checkboxes below are rights that can be given directly to this group.',
    'lock' => 'Zakljucaj',
    'members' => 'Clanovi',
    'anonymous' => 'Anonimac',
    'permissions' => 'Prava',
    'permissionskey' => 'R = cita, E = Editira, pravo editiranja ukljucuje i pravo citanja',
    'edit' => 'Edituj',
    'none' => 'None',
    'accessdenied' => 'Pristup odbijen',
    'storydenialmsg' => "You do not have access to view this story.  This could be because you aren't a member of {$_CONF['site_name']}.  Please <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> become a member</a> of {$_CONF['site_name']} to receive full membership access!",
    'nogroupsforcoregroup' => 'This group doesn\'t belong to any of the other groups',
    'grouphasnorights' => 'This group doesn\'t have access to any of the administrative features of this site',
    'newgroup' => 'Nova Grupa',
    'adminhome' => 'Admin Home',
    'save' => 'snimi',
    'cancel' => 'odustani',
    'delete' => 'izbrisi',
    'canteditroot' => 'You have tried to edit the Root group but you are not in the Root group yourself therefore your access to this group is denied.  Please contact the system administrator if you feel this is an error.',
    'listusers' => 'Lista korisnika',
    'listthem' => 'lista',
    'usersingroup' => 'Korisnici u grupi "%s"',
    'usergroupadmin' => 'Administrator korisnicke grupe',
    'add' => 'Dodaj',
    'remove' => 'Makni',
    'availmembers' => 'Aktivni clanovi',
    'groupmembers' => 'Clanovi grupe',
    'canteditgroup' => 'To edit this group, you have to be a member of the group. Please contact the system administrator if you feel this is an error.',
    'cantlistgroup' => 'To see the members of this group, you have to be a member yourself. Please contact the system administrator if you feel this is an error.',
    'editgroupmsg' => 'To modify the group membership, click on the member names(s) and use the add or remove buttons. If the member is a member of the group, their name will appear on the right side only. Once you are complete - press <b>Save</b> to update the group and return to the main group admin page.',
    'listgroupmsg' => 'Listing of all current members in the group: <b>%s</b>',
    'search' => 'Search',
    'submit' => 'Submit',
    'limitresults' => 'Limit Results',
    'group_id' => 'Group ID',
    'plugin_access_denied_msg' => 'You are illegally trying access a plugin administration page.  Please note that all attempts to illegally access this page are logged.',
    'groupexists' => 'Group name already exists',
    'groupexistsmsg' => 'There is already a group with this name. Group names must be unique.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => 'Posljednih 10 backupova.',
    'do_backup' => 'Napravi sigurnosnu kopiju',
    'backup_successful' => 'Backup baze podataka je uspjesno napravljen.',
    'db_explanation' => 'Da bi napravili sigurnosu kopiju kliknite ovdje dole.',
    'not_found' => "Incorrect path or mysqldump utility not executable.<br" . XHTML . ">Check <strong>\$_DB_mysqldump_path</strong> definition in config.php.<br" . XHTML . ">Variable currently defined as: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Backup Failed: Filesize was 0 bytes',
    'path_not_found' => "{$_CONF['backup_path']} nepostoji ili nije direktorij",
    'no_access' => "GRESKA: Direktorij {$_CONF['backup_path']} nije dostupan.",
    'backup_file' => 'Backup file',
    'size' => 'Velicina',
    'bytes' => 'Bytes',
    'total_number' => 'Ukupan broj sigurnosnih backupova: %d',
    'download' => 'Click to download this file',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Pocetna stranica',
    2 => 'Kontakt',
    3 => 'Posaljite Vijest',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Statistika stranice',
    8 => 'Personalizacija',
    9 => 'Pretraga',
    10 => 'napredna pretraga',
    11 => 'Directory'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => '404 Error',
    2 => 'Oj, gledao sam svugdje, ali nigdje nemogu naci <b>%s</b>.',
    3 => "<p>Zao nam je, ali file koji ste trazili ne postoji. Mozda cete vise srece imati sa <a href=\"{$_CONF['site_url']}\">glavnom stranicom</a> ili sa <a href=\"{$_CONF['site_url']}/search.php\">pretragom</a> da biste nasli ono sto ste zijanili :)."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Potrebna prijava',
    2 => 'Zao mi je. Da bi pristupili ovdje morate biti registrirani korisnik..',
    3 => 'Prijava',
    4 => 'Novi korisnik'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'from',
    'tracked_on' => 'Tracked on',
    'read_more' => '[read more]',
    'intro_text' => 'Here\'s what others have to say about \'%s\':',
    'no_comments' => 'No trackback comments for this entry.',
    'this_trackback_url' => 'Trackback URL for this entry:',
    'num_comments' => '%d trackback comments',
    'send_trackback' => 'Send Pings',
    'preview' => 'Preview',
    'editor_title' => 'Send trackback comment',
    'trackback_url' => 'Trackback URL',
    'entry_url' => 'Entry URL',
    'entry_title' => 'Entry Title',
    'blog_name' => 'Site Name',
    'excerpt' => 'Excerpt',
    'truncate_warning' => 'Note: The receiving site may truncate your excerpt',
    'button_send' => 'Send',
    'button_preview' => 'Preview',
    'send_error' => 'Error',
    'send_error_details' => 'Error when sending trackback comment:',
    'url_missing' => 'No Entry URL',
    'url_required' => 'Please enter at least a URL for the entry.',
    'target_missing' => 'No Trackback URL',
    'target_required' => 'Please enter a trackback URL',
    'error_socket' => 'Could not open socket.',
    'error_response' => 'Response not understood.',
    'error_unspecified' => 'Unspecified error.',
    'select_url' => 'Select Trackback URL',
    'not_found' => 'Trackback URL not found',
    'autodetect_failed' => 'Geeklog could not detect the Trackback URL for the post you want to send your comment to. Please enter it manually below.',
    'trackback_explain' => 'From the links below, please select the URL you want to send your Trackback comment to. Geeklog will then try to determine the correct Trackback URL for that post. Or you can <a href="%s">enter it manually</a> if you know it already.',
    'no_links_trackback' => 'No links found. You can not send a Trackback comment for this entry.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback results',
    'send_pings' => 'Send Pings',
    'send_pings_for' => 'Send Pings for "%s"',
    'no_links_pingback' => 'No links found. No Pingbacks were sent for this entry.',
    'pingback_success' => 'Pingback sent.',
    'no_pingback_url' => 'No pingback URL found.',
    'resend' => 'Resend',
    'ping_all_explain' => 'You can now notify the sites you linked to (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), advertise that your site has been updated by pinging weblog directory services, or send a <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> comment in case you wrote about a post on someone else\'s site.',
    'pingback_button' => 'Send Pingback',
    'pingback_short' => 'Send Pingbacks to all sites linked from this entry.',
    'pingback_disabled' => '(Pingback disabled)',
    'ping_button' => 'Send Ping',
    'ping_short' => 'Ping weblog directory services.',
    'ping_disabled' => '(Ping disabled)',
    'trackback_button' => 'Send Trackback',
    'trackback_short' => 'Send a Trackback comment.',
    'trackback_disabled' => '(Trackback disabled)',
    'may_take_a_while' => 'Please note that sending Pingbacks and Pings may take a while.',
    'ping_results' => 'Ping results',
    'unknown_method' => 'Unknown ping method',
    'ping_success' => 'Ping sent.',
    'error_site_name' => 'Please enter the site\'s name.',
    'error_site_url' => 'Please enter the site\'s URL.',
    'error_ping_url' => 'Please enter a valid Ping URL.',
    'no_services' => 'No weblog directory services configured.',
    'services_headline' => 'Weblog Directory Services',
    'service_explain' => 'To modify or delete a weblog directory service, click on the edit icon of that service below. To add a new weblog directory service, click on "Create New" above.',
    'service' => 'Service',
    'ping_method' => 'Ping method',
    'service_website' => 'Website',
    'service_ping_url' => 'URL to ping',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Extended Ping',
    'ping_unknown' => '(unknown method)',
    'edit_service' => 'Edit Weblog Directory Service',
    'trackbacks' => 'Trackbacks',
    'editor_intro' => 'Prepare your trackback comment for <a href="%s">%s</a>.',
    'editor_intro_none' => 'Prepare your trackback comment.',
    'trackback_note' => 'To send a trackback comment for a story, go to the list of stories and click on "Send Ping" for the story. To send a trackback that is not related to a story, <a href="%s">click here</a>.',
    'pingback_explain' => 'Enter a URL to send the Pingback to. The pingback will point to your site\'s homepage.',
    'pingback_url' => 'Pingback URL',
    'site_url' => 'This site\'s URL',
    'pingback_note' => 'To send a pingback for a story, go to the list of stories and click on "Send Ping" for the story. To send a pingback that is not related to a story, <a href="%s">click here</a>.',
    'pbtarget_missing' => 'No Pingback URL',
    'pbtarget_required' => 'Please enter a pingback URL',
    'pb_error_details' => 'Error when sending the pingback:',
    'delete_trackback' => 'To delete this Trackback click: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Article Directory',
    'title_year' => 'Article Directory for %d',
    'title_month_year' => 'Article Directory for %s %d',
    'nav_top' => 'Back to Article Directory',
    'no_articles' => 'No articles.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n new %i in the last %t %s',
    'new_last' => 'last %t %s',
    'minutes' => 'minutes',
    'hours' => 'hours',
    'days' => 'days',
    'weeks' => 'weeks',
    'months' => 'months',
    'minute' => 'minute',
    'hour' => 'hour',
    'day' => 'day',
    'week' => 'week',
    'month' => 'month'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'Januar',
    2 => 'Februar',
    3 => 'Mart',
    4 => 'April',
    5 => 'Maj',
    6 => 'Juni',
    7 => 'Juli',
    8 => 'August',
    9 => 'Septembar',
    10 => 'Oktobar',
    11 => 'Novembar',
    12 => 'Decembar'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'Nedelja',
    2 => 'Ponedeljak',
    3 => 'Utorak',
    4 => 'Srijeda',
    5 => 'Cetvrtak',
    6 => 'Petak',
    7 => 'Subota'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Search',
    'limit_results' => 'Limit Results',
    'submit' => 'Submit',
    'edit' => 'Edit',
    'edit_adv' => 'Adv. Edit',
    'admin_home' => 'Admin Home',
    'create_new' => 'Create New',
    'create_new_adv' => 'Create New (Adv.)',
    'enabled' => 'Enabled',
    'title' => 'Title',
    'page_title' => 'Page Title',
    'type' => 'Type',
    'topic' => 'Topic',
    'help_url' => 'Help File URL',
    'save' => 'Save',
    'cancel' => 'Cancel',
    'delete' => 'Delete',
    'delete_sel' => 'Delete selected',
    'copy' => 'Copy',
    'no_results' => '- No entries found -',
    'data_error' => 'There was an error processing the subscription data. Please check the data source.',
    'preview' => 'Preview',
    'records_found' => 'Records found',
    'addchild' => 'Add child',
    'list' => 'list',
    'list_all' => 'List all',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
    'authenticate' => 'Authenticate'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Comments Enabled',
    -1 => 'Comments Disabled',
    1 => 'Comments Closed'
);

$LANG_commentmodes = array(
    'flat' => 'Flat',
    'nested' => 'Nested',
    'threaded' => 'Threaded',
    'nocomment' => 'No Comments'
);

$LANG_cookiecodes = array(
    0 => '(don\'t)',
    3600 => '1 Hour',
    7200 => '2 Hours',
    10800 => '3 Hours',
    28800 => '8 Hours',
    86400 => '1 Day',
    604800 => '1 Week',
    2678400 => '1 Month'
);

$LANG_dateformats = array(
    0 => 'System Default'
);

$LANG_featurecodes = array(
    0 => 'Not Featured',
    1 => 'Featured'
);

$LANG_frontpagecodes = array(
    0 => 'Show Only in Topic',
    1 => 'Show on Front Page'
);

$LANG_postmodes = array(
    'plaintext' => 'Plain Old Text',
    'html' => 'HTML Formatted'
);

$LANG_sortcodes = array(
    'ASC' => 'Oldest First',
    'DESC' => 'Newest First'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback Enabled',
    -1 => 'Trackback Disabled'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Site Administration',
    'sections' => 'Configuration Sections',
    'restore' => 'Restore',
    'add_element' => 'Add Element',
    'save_changes' => 'Save Changes',
    'reset_form' => 'Reset Form',
    'changes_made' => 'Changes were successfully made to',
    'title' => 'Configuration Manager',
    'disable' => 'Click to disable this option',
    'enable' => 'Enable'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog Configuration'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML Path',
    'site_url' => 'Site URL',
    'site_admin_url' => 'Admin URL',
    'site_mail' => 'Site E-Mail',
    'noreply_mail' => 'No-Reply E-Mail',
    'site_name' => 'Site Name',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Log',
    'path_language' => 'Language',
    'backup_path' => 'Backup',
    'path_data' => 'Data',
    'path_images' => 'Images',
    'path_pear' => 'Path Pear',
    'have_pear' => 'Have Pear?',
    'mail_settings' => 'Mail Settings',
    'allow_mysqldump' => 'Allow MySQL Dump',
    'mysqldump_path' => 'Path of Executable',
    'mysqldump_options' => 'MySQL Dump Options',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Theme',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Menu Elements',
    'path_themes' => 'Themes Path',
    'disable_new_user_registration' => 'Disable New Registrations',
    'allow_user_themes' => 'Allow User Themes',
    'allow_user_language' => 'Allow User Language',
    'allow_user_photo' => 'Allow User Photo',
    'allow_username_change' => 'Allow Username Changes',
    'allow_account_delete' => 'Allow Account Deletion',
    'hide_author_exclusion' => 'Allow Hide Author',
    'show_fullname' => 'Show Fullname',
    'show_servicename' => 'Show Service Name',
    'custom_registration' => 'Enable Custom Registration',
    'user_login_method' => 'User Login Method',
    'spamx' => 'Spam-X Actions',
    'sort_admin' => 'Sort Links',
    'language' => 'Language',
    'locale' => 'Locale',
    'date' => 'Date Format',
    'daytime' => 'Daytime Format',
    'shortdate' => 'Short Date Format',
    'dateonly' => 'Date Only Format',
    'timeonly' => 'Time Only Format',
    'week_start' => 'Week Start',
    'hour_mode' => 'Hour Mode',
    'thousand_separator' => 'Thousands Separator',
    'decimal_separator' => 'Decimal Separator',
    'decimal_count' => 'Decimal Count',
    'language_files' => 'Language Files',
    'languages' => 'Languages',
    'timezone' => 'Timezone',
    'site_disabled_msg' => 'Site Disabled Message or URL',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Session Cookie Name',
    'cookie_name' => 'Permanent Cookie Name',
    'cookie_password' => 'Password Cookie Name',
    'cookie_theme' => 'Theme Cookie Name',
    'cookie_language' => 'Language Cookie Name',
    'cookie_tzid' => 'Timezone Cookie Name',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Cookies embed IP?',
    'default_perm_cookie_timeout' => 'Permanent Timeout',
    'session_cookie_timeout' => 'Session Timeout',
    'cookie_path' => 'Cookie Path',
    'cookiedomain' => 'Cookie Domain',
    'cookiesecure' => 'Cookie Secure',
    'lastlogin' => 'Record Last Login?',
    'num_search_results' => 'Number of Search Results',
    'loginrequired' => 'Login Required?',
    'submitloginrequired' => 'Submit Login Required?',
    'commentsloginrequired' => 'Comment Login Required?',
    'statsloginrequired' => 'Stats Login Required?',
    'searchloginrequired' => 'Search Login Required?',
    'profileloginrequired' => 'Profile Login Required?',
    'emailuserloginrequired' => 'E-Mail User Login Required?',
    'emailstoryloginrequired' => 'E-Mail Story Login Required?',
    'directoryloginrequired' => 'Directory Login Required?',
    'storysubmission' => 'Story Submission Queue?',
    'usersubmission' => 'User Submission Queue?',
    'listdraftstories' => 'List Draft Stories?',
    'notification' => 'Notifications',
    'postmode' => 'Default Post Mode',
    'speedlimit' => 'Post Speed Limit',
    'skip_preview' => 'Skip Preview in Posts',
    'advanced_editor' => 'Advanced Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Schedule Interval',
    'sortmethod' => 'Sort Topics',
    'showstorycount' => 'Show Story Count?',
    'showsubmissioncount' => 'Show Submission Count?',
    'hide_home_link' => 'Hide Home Link?',
    'whosonline_threshold' => 'Session Threshold',
    'whosonline_anonymous' => 'Hide Names from Guests?',
    'emailstories' => 'Daily Digest Enabled?',
    'emailstorieslength' => 'Length of Stories',
    'emailstoriesperdefault' => 'Enable for New Users?',
    'allow_domains' => 'Automatic Allow Domains',
    'disallow_domains' => 'Automatic Disallow Domains',
    'newstoriesinterval' => 'New Stories Interval',
    'newcommentsinterval' => 'New Comments Interval',
    'newtrackbackinterval' => 'New Trackbacks Interval',
    'hidenewstories' => 'Hide New Stories',
    'hidenewcomments' => 'Hide New Comments',
    'hidenewtrackbacks' => 'Hide New Trackbacks',
    'hidenewplugins' => 'Hide New Plugin Entries',
    'title_trim_length' => 'Title Trim Length',
    'trackback_enabled' => 'Trackback Enabled?',
    'pingback_enabled' => 'Pingback Enabled?',
    'ping_enabled' => 'Ping Enabled?',
    'trackback_code' => 'Trackback Default',
    'multiple_trackbacks' => 'Multiple Trackbacks',
    'trackbackspeedlimit' => 'Trackback Speed Limit',
    'check_trackback_link' => 'Check Trackbacks',
    'pingback_self' => 'Pingback Self?',
    'pingback_excerpt' => 'Create Pingback Excerpt?',
    'link_documentation' => 'Link to Documentation?',
    'link_versionchecker' => 'Link to Version Checker?',
    'maximagesperarticle' => 'Max Images per Article',
    'limitnews' => 'Stories per Page',
    'minnews' => 'Min. Stories per Page',
    'contributedbyline' => 'Show "Contributed By"?"',
    'hideviewscount' => 'Hide Views Count?',
    'hideemailicon' => 'Hide E-Mail Icon?',
    'hideprintericon' => 'Hide Print Icon?',
    'allow_page_breaks' => 'Allow Page Breaks?',
    'page_break_comments' => 'Comments on Multi-Page Articles',
    'article_image_align' => 'Topic Icon Alignment',
    'show_topic_icon' => 'Show Topic Icon?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Frontpage Default',
    'hide_no_news_msg' => 'Hide "No News" Message?',
    'hide_main_page_navigation' => 'Hide Main Page Navigation?',
    'onlyrootfeatures' => 'Only Root can Feature?',
    'aftersave_story' => 'After Saving Story',
    'aftersave_user' => 'After Saving User',
    'show_right_blocks' => 'Always Show Right Blocks?',
    'showfirstasfeatured' => 'Show First Story as Featured?',
    'backend' => 'Enable Feeds?',
    'rdf_file' => 'Syndication Output Folder',
    'rdf_limit' => 'Feed Limit',
    'rdf_storytext' => 'Length of Stories in Feed',
    'rdf_language' => 'Feed Language',
    'syndication_max_headlines' => 'Max. Number of Headlines (portal blocks)',
    'copyrightyear' => 'Copyright Year',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Path to Mogrify',
    'path_to_netpbm' => 'Path to Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Allow User Scaling?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Image Width?',
    'max_image_height' => 'Max Image Height?',
    'max_image_size' => 'Max Image Size?',
    'max_topicicon_width' => 'Max Topic Icon Width?',
    'max_topicicon_height' => 'Max Topic Icon Height?',
    'max_topicicon_size' => 'Max Topic Icon Size?',
    'max_photo_width' => 'Max Photo Width?',
    'max_photo_height' => 'Max Photo Height?',
    'max_photo_size' => 'Max Photo Size?',
    'use_gravatar' => 'Use Gravatar?',
    'gravatar_rating' => 'Gravatar Rating',
    'force_photo_width' => 'Force Photo Width',
    'default_photo' => 'Default Photo',
    'commentspeedlimit' => 'Comment Speed Limit',
    'comment_limit' => 'Comment Limit',
    'comment_mode' => 'Comment Mode',
    'comment_code' => 'Comment Default',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Password Speed Limit',
    'login_attempts' => 'Max. Login Attempts',
    'login_speedlimit' => 'Login Speed Limit',
    'user_html' => 'User HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
    'allowed_protocols' => 'Allowed Protocols',
    'disable_autolinks' => 'Disable Autotags?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Censor Mode?',
    'censorreplace' => 'Censor Replace Text',
    'censorlist' => 'Censor List',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Enable URL Rewrite',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Block Default Permissions',
    'default_permissions_story' => 'Story Default Permissions',
    'default_permissions_topic' => 'Topic Default Permissions',
    'atom_max_stories' => 'Max. Stories in Webservices Feed',
    'disable_webservices' => 'Disable Webservices?',
    'restrict_webservices' => 'Restrict Webservices?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method',
    'search_def_sort' => 'Default Sort Order'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Site',
    'sg_stories' => 'Stories and Trackback',
    'sg_theme' => 'Theme',
    'sg_blocks' => 'Blocks',
    'sg_users' => 'Users and Submissions',
    'sg_images' => 'Images',
    'sg_locale' => 'Languages and Locale',
    'sg_misc' => 'Miscellaneous'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Site',
    'fs_paths' => 'Paths',
    'fs_theme' => 'Theme',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Users',
    'fs_misc' => 'Miscellaneous',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Block',
    'fs_locale' => 'Locale',
    'fs_language' => 'Language',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Cookies',
    'fs_login' => 'Login Settings',
    'fs_search' => 'Search',
    'fs_user_submission' => 'User Submission',
    'fs_submission' => 'Submission Settings',
    'fs_topics_block' => 'Topics Block',
    'fs_whosonline_block' => 'Who\'s Online Block',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'What\'s New Block',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Story',
    'fs_theme_advanced' => 'Advanced Settings',
    'fs_syndication' => 'Syndication',
    'fs_imagelib' => 'Image Library',
    'fs_upload' => 'Upload',
    'fs_articleimg' => 'Images in Articles',
    'fs_topicicon' => 'Topic Icons',
    'fs_userphoto' => 'Photos',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Comments',
    'fs_htmlfilter' => 'HTML Filtering',
    'fs_censoring' => 'Censoring',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Story Default Permission',
    'fs_perm_topic' => 'Topic Default Permission',
    'fs_perm_block' => 'Block Default Permission',
    'fs_webservices' => 'Webservices'
);

$LANG_configselects['Core'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('Reject' => 0, 'Only Keep Latest' => 1, 'Allow Multiple Posts' => 2),
    3 => array('Trackback Enabled' => 0, 'Trackback Disabled' => -1),
    4 => array('Don\'t Check Anything' => 0, 'Check against Site URL' => 1, 'Check full URL' => 2, 'Check against Site URL and full URL' => 3, 'Check IP against Site IP' => 4, 'Check IP and Site URL' => 5, 'Check IP and Full URL' => 6, 'Check IP, Full URL, and Site URL' => 7),
    5 => array('Plain Old Text' => 'plaintext', 'HTML Formatted' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Last Page' => 'last', 'First Page' => 'first', 'Every Page' => 'all'),
    8 => array('Right' => 'right', 'Left' => 'left'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    10 => array('None' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
    13 => array('Skip' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
    14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
    15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
    16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
);

?>
